.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the PyMVPA package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. _chap_code_swarm:
.. index:: code swarm

******************
PyMVPA - The Movie
******************

If you are interested in the evolution of PyMVPA you might also be interested
in the following movie. It is a visualization of the activity in the PyMVPA
source repository since it first has been published in May 2007. The movie is
generated with tools from the `code_swarm project`_.

.. _code_swarm project: http://vis.cs.ucdavis.edu/~ogawa/codeswarm/

In the movie, each file in the PyMVPA sources that is changed appears as a
particle on the screen centered around the name of the developer that
contributed this change. The colors indicate which part of PyMVPA the
respective file belongs to (see the legend on the left). The animation is
regenerated every couple of weeks to include the more recent commits.

.. raw:: html

  <script src="/swf/flowplayer.min.js"></script>
  <a href="http://www.pymvpa.org/files/pymvpa-codeswarm.flv"
     style="display:block;width:480px;height:360px" id="player">
    <img src="_images/history_splash.png" alt="Play video" border="0" /></a>
  <script language="JavaScript">
    flowplayer("player", "/swf/flowplayer.swf");
  </script>

Music by `Peter Nalitch`_. Many thanks for his special permission to use his
song *Gitar* (© Peter Nalitch) for our project history. Please be sure to also
watch the `outstanding video clip`_! 

.. _Peter Nalitch: http://peternalitch.ru
.. _outstanding video clip: http://www.youtube.com/watch?v=AOzkN8dHnjk
